=============
ase-stubs
=============

This project provides stub files for ASE_ to be used by type-checkers such as Mypy_ or Pyright_.

.. _Mypy: https://mypy.readthedocs.io/
.. _Pyright: https://github.com/microsoft/pyright

Requirements
============

* ASE_ (tools for atomistic simulations)

.. _ASE: https://wiki.fysik.dtu.dk/ase/index.html

Installation
============

::

    $ pip install ase-stubs

or, if you use poetry::

    $ poetry add ase-stubs

You can also install the in-development version with::

    $ pip install git+ssh://git@gitlab.com:ugognw/ase-stubs.git

or, similarly::

    $ poetry add git+ssh://git@gitlab.com:ugognw/ase-stubs.git
